from neo4j import GraphDatabase
import sys
def count_node(uri,user,pwd):
    try:
        driver=GraphDatabase.driver(uri=uri,auth=(user,pwd))
        connect=1
    except (ValueError,OSError,AuthError) as e:
        sys.exit("check for hostname , username and password")
    if(connect==1):
        session=driver.session()
        count_query="""match (n) return count(n) as count"""
        count_result=session.run(count_query)
        for count in count_result:
            nodecount=count["count"]
        return nodecount
    


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="allneo",
    author="RONI DAS",
    version="5.0.0",
    author_email="roni@totaltechnology.in",
    description="complete package for neo4j developed by Roni Das",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    install_requires=["neo4j"],
    python_requires=">=3.7",
)